summaryrefslogtreecommitdiff
path: root/src/char/char.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/char/char.c')
-rw-r--r--src/char/char.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/char/char.c b/src/char/char.c
index d56c79b28..c99c1e3c4 100644
--- a/src/char/char.c
+++ b/src/char/char.c
@@ -1003,7 +1003,7 @@ int mmo_char_init(void)
if (!char_dat) {
ShowFatalError("Out of memory: mmo_char_init (realloc of char_dat).\n");
char_log("Out of memory: mmo_char_init (realloc of char_dat).\n");
- exit(1);
+ exit(EXIT_FAILURE);
}
}
@@ -1227,7 +1227,7 @@ int make_new_char(struct char_session_data* sd, char* name_, int str, int agi, i
if (!char_dat) {
ShowFatalError("Out of memory: make_new_char (realloc of char_dat).\n");
char_log("Out of memory: make_new_char (realloc of char_dat).\n");
- exit(1);
+ exit(EXIT_FAILURE);
}
}
@@ -1993,7 +1993,7 @@ int parse_fromlogin(int fd)
ShowError("The server communication passwords (default s1/p1) are probably invalid.\n");
ShowInfo("Also, please make sure your accounts file (default: accounts.txt) has those values present.\n");
ShowInfo("The communication passwords can be changed in map_athena.conf and char_athena.conf\n");
//exit(1); //fixed for server shutdown.
} else {
ShowStatus("Connected to login-server (connection #%d).\n", fd);
@@ -1993,7 +1993,7 @@ int parse_fromlogin(int fd)
ShowInfo("Also, please make sure your accounts file (default: accounts.txt) has those values present.\n");
ShowInfo("The communication passwords can be changed in map_athena.conf and char_athena.conf\n");
- //exit(1); //fixed for server shutdown.
+ //exit(EXIT_FAILURE); //fixed for server shutdown.
} else {
ShowStatus("Connected to login-server (connection #%d).\n", fd);